==> haskell-gnutls-0.2-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gnutls
version:              0.2
visibility:           public
id:                   gnutls-0.2-29mnlrChRYPH2v6b0yw34Z
key:                  gnutls-0.2-29mnlrChRYPH2v6b0yw34Z
license:              GPL-3.0-only
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-gnutls/
synopsis:             Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.

    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.

category:             Network
abi:                  449bd0f8be60a088c94e01b893568d4c
exposed:              True
exposed-modules:      Network.Protocol.TLS.GNU
hidden-modules:
    Network.Protocol.TLS.GNU.ErrorT Network.Protocol.TLS.GNU.Foreign

import-dirs:          /usr/lib/ghc-8.10.1/site-local/gnutls-0.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/gnutls-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/gnutls-0.2
hs-libraries:         HSgnutls-0.2-29mnlrChRYPH2v6b0yw34Z
extra-libraries:      gnutls gnutls
include-dirs:         /usr/include/p11-kit-1
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    monads-tf-0.1.0.3-7PM8YidPv9U2z3216iOBXG transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html:         /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gnutls-0.2-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gnutls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gnutls
version:              0.2
visibility:           public
id:                   gnutls-0.2-FBzkR7Y1CQKBUZNvH3Nath
key:                  gnutls-0.2-FBzkR7Y1CQKBUZNvH3Nath
license:              GPL-3.0-only
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/haskell-gnutls/
synopsis:             Bindings for GNU libgnutls
description:
    You almost certainly don'\''t want to depend on this release.

    This is a pre-alpha, almost useless release; its only purpose is to enable
    TLS support in some of my other libraries. More complete bindings for GNU TLS
    will be released at a later date.

category:             Network
abi:                  3a5b74338cbe0c436a978cdaf1e4877f
exposed:              True
exposed-modules:      Network.Protocol.TLS.GNU
hidden-modules:
    Network.Protocol.TLS.GNU.ErrorT Network.Protocol.TLS.GNU.Foreign

import-dirs:          /usr/lib/ghc-8.10.2/site-local/gnutls-0.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/gnutls-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/gnutls-0.2
hs-libraries:         HSgnutls-0.2-FBzkR7Y1CQKBUZNvH3Nath
extra-libraries:      gnutls gnutls
include-dirs:         /usr/include/p11-kit-1
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    monads-tf-0.1.0.3-ETMQNdBlDWfJbOkLMFyAzV transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gnutls/html/gnutls.haddock
haddock-html:         /usr/share/doc/haskell-gnutls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
